==> content_management-0.1.0.gem: app/controllers/content_management/admin/trackbacks_controller.rb <==
module ContentManagement
  class Admin::TrackbacksController < ContentManagementController
    # GET /trackbacks
    # GET /trackbacks.json
    def index
      @trackbacks = Trackback.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @trackbacks }
      end
    end

    # GET /trackbacks/1
    # GET /trackbacks/1.json
    def show
      @trackback = Trackback.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @trackback }
      end
    end

    # GET /trackbacks/new
    # GET /trackbacks/new.json
    def new
      @trackback = Trackback.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @trackback }
      end
    end

    # GET /trackbacks/1/edit
    def edit
      @trackback = Trackback.find(params[:id])
    end

    # POST /trackbacks
    # POST /trackbacks.json
    def create
      @trackback = Trackback.new(params[:trackback])

      respond_to do |format|
        if @trackback.save
          format.html { redirect_to @trackback, :notice => 'Trackback was successfully created.' }
          format.json { render :json => @trackback, :status => :created, :location => @trackback }
        else
          format.html { render :action => "new" }
          format.json { render :json => @trackback.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /trackbacks/1
    # PUT /trackbacks/1.json
    def update
      @trackback = Trackback.find(params[:id])

      respond_to do |format|
        if @trackback.update_attributes(params[:trackback])
          format.html { redirect_to @trackback, :notice => 'Trackback was successfully updated.' }
          format.json { head :ok }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @trackback.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /trackbacks/1
    # DELETE /trackbacks/1.json
    def destroy
      @trackback = Trackback.find(params[:id])
      @trackback.destroy

      respond_to do |format|
        format.html { redirect_to trackbacks_url }
        format.json { head :ok }
      end
    end
  end
end

==> content_management-0.1.4.gem: app/controllers/content_management/admin/trackbacks_controller.rb <==
module ContentManagement
  class Admin::TrackbacksController < ContentManagementController
    # GET /trackbacks
    # GET /trackbacks.json
    def index
      @trackbacks = Trackback.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @trackbacks }
      end
    end

    # GET /trackbacks/1
    # GET /trackbacks/1.json
    def show
      @trackback = Trackback.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @trackback }
      end
    end

    # GET /trackbacks/new
    # GET /trackbacks/new.json
    def new
      @trackback = Trackback.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @trackback }
      end
    end

    # GET /trackbacks/1/edit
    def edit
      @trackback = Trackback.find(params[:id])
    end

    # POST /trackbacks
    # POST /trackbacks.json
    def create
      @trackback = Trackback.new(params[:trackback])

      respond_to do |format|
        if @trackback.save
          format.html { redirect_to @trackback, notice: 'Trackback was successfully created.' }
          format.json { render json: @trackback, status: :created, location: @trackback }
        else
          format.html { render action: 'new' }
          format.json { render json: @trackback.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /trackbacks/1
    # PUT /trackbacks/1.json
    def update
      @trackback = Trackback.find(params[:id])

      respond_to do |format|
        if @trackback.update_attributes(params[:trackback])
          format.html { redirect_to @trackback, notice: 'Trackback was successfully updated.' }
          format.json { head :ok }
        else
          format.html { render action: 'edit' }
          format.json { render json: @trackback.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /trackbacks/1
    # DELETE /trackbacks/1.json
    def destroy
      @trackback = Trackback.find(params[:id])
      @trackback.destroy

      respond_to do |format|
        format.html { redirect_to trackbacks_url }
        format.json { head :ok }
      end
    end
  end
end
